from datetime import datetime
import calendar
from injectable import injectable


@injectable
class UtilsTime:
    def get_current_timestamp_ms(self) -> int:
        return int(round(datetime.now().timestamp() * 1000))

    def get_number_of_days_in_month(self, year: int, month: int) -> int:
        x, number_of_days_in_month = calendar.monthrange(year, month)
        return number_of_days_in_month



from injectable import injectable


@injectable
class UtilsClass:
    def get_full_class_name(self, obj):
        module = obj.__class__.__module__
        if module is None or module == str.__class__.__module__:
            return obj.__class__.__name__
        return module + '.' + obj.__class__.__name__



from setuptools import setup, find_packages


with open("README.md", "r") as readme_file:
    readme_text = readme_file.read()


setup_args = dict(
    name='tekleo-common-utils',
    version='0.0.0.1',
    description="",
    keywords=[],
    long_description=readme_text,
    long_description_content_type="text/markdown",
    license='Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 International Public License',
    packages=find_packages(),
    author="Leo Ertuna",
    author_email="leo.ertuna@gmail.com",
    url="https://github.com/jpleorx/tekleo-common-utils",
    download_url='https://pypi.org/project/tekleo-common-utils/'
)


install_requires = [
    'injectable',
]


if __name__ == '__main__':
    setup(**setup_args, install_requires=install_requires)
